flipper package
===============

.. automodule:: flipper

Subpackages
-----------

flipper.kernel
~~~~~~~~~~~~~~

.. automodule:: flipper.kernel

.. rubric:: Classes

.. autosummary::
    :toctree: ../generated
    :nosignatures:
    :template: summary.rst

    ~bundle.Bundle
    ~encoding.Encoding
    ~equippedtriangulation.EquippedTriangulation
    ~error.AbortError
    ~error.ApproximationError
    ~error.AssumptionError
    ~error.ComputationError
    ~error.FatalError
    ~flatstructure.FlatStructure
    ~flatstructure.Vector2
    ~lamination.Lamination
    ~matrix.Matrix
    ~moves.EdgeFlip
    ~moves.Isometry
    ~moves.LinearTransformation
    ~moves.Move
    ~permutation.Permutation
    ~splittingsequence.SplittingSequence
    ~splittingsequence.SplittingSequences
    ~triangulation.Corner
    ~triangulation.Edge
    ~triangulation.Triangle
    ~triangulation.Triangulation
    ~triangulation.Vertex
    ~triangulation3.Tetrahedron
    ~triangulation3.Triangulation3

Submodules
----------

flipper.census module
~~~~~~~~~~~~~~~~~~~~~

.. automodule:: flipper.census
    :members:
    :undoc-members:
    :inherited-members:
    :show-inheritance:

flipper.load module
~~~~~~~~~~~~~~~~~~~

.. automodule:: flipper.load
    :members:
    :undoc-members:
    :inherited-members:
    :show-inheritance:

flipper.surface module
~~~~~~~~~~~~~~~~~~~~~~

.. automodule:: flipper.surface
    :members:
    :undoc-members:
    :inherited-members:
    :show-inheritance:

